/******************************************************************************/
//
// Name: 	Interfacing ADSP-21365 with AD7676 
//
/******************************************************************************

(C) Copyright 2004 - Analog Devices, Inc.  All rights reserved.

File Name:		ADSP-21365_SerialPort_with_AD7676.asm

Date Modified:	08/20/04				Rev 1.0

Software:       VisualDSP++3.5 (July update)

Purpose:		To receive data from AD7676
				
*******************************************************************************/

#include <def21365.h>
#include <SRU.h>

#define FRAMED_MODE
//#define UNFRAMED_MODE

.section/dm seg_dmda;
	.var adc_data;
	.var counter = 0;

.section/pm seg_rth;
	nop;nop;nop;nop;
  	nop;jump start;

 // Sport 1 receive interrupt
.section/pm seg_sp;
	nop;jump isr; rti;rti;
	
.section/pm seg_pmco;
start:
	// Route the serial port signals to DAI pins
	call SRU_Init;
	
	// Configure TFS (CONVST) to be generated continuously
	r0 = 0x0;
	dm(SPCTL0) = r0;

	r0 = 0x120012;
	dm(DIV0) = r0;
	
	r0 = DITFS | SPEN_A | SLEN32 | LFS | ICLK | IFS | FSR | SPTRAN;
	dm(SPCTL0) = r0;
	
	r0 = 0x12345678;
 	dm(TXSP0A) = r0;

 	// Enable interrupts
	bit set mode1 IRPTEN;
	bit set imask P3I; // By default SPORT 1 interrupt is mapped to Peripheral interrupt 3
	 
	r0 = 0x0;
	dm(SPCTL1) = r0;
	
	r1 = 0x0;
	r7 = 0x2;
	
#ifdef UNFRAMED_MODE	
	r0 = SPEN_A|SLEN15|LFS|LAFS|CKRE;
#endif
#ifdef FRAMED_MODE
	r0 = SPEN_A|SLEN15|LFS|LAFS|FSR|CKRE;
#endif
	dm(SPCTL1) = r0;
	
	nop;
	nop;
	jump(pc,0);
	
.section/pm seg_pmco;
isr:
	r3 = dm(RXSP1A);

	// If it is the first word received, reconfigure the sport for
	// 16 bits
	r0 = dm(counter);
	comp(r0,r1);
	if eq jump reconfigure;
	
	// Incrementing the counter
	r6 = dm(counter);
	r6 = r6 + 1;
	dm(counter) = r6;
	
	comp(r6,r7);
	if eq rti;
	
	dm(adc_data) = r3;
	rti;

.section/pm seg_pmco;
reconfigure:
	// Reconfiguring the serial port for 16 bits.
#ifdef UNFRAMED_MODE
	r0 = SPEN_A|SLEN16|LFS|LAFS|CKRE;
#endif
	
#ifdef FRAMED_MODE
	r0 = SPEN_A|SLEN16|LFS|LAFS|FSR|CKRE;
#endif
	dm(SPCTL1) = r0;
	
	r2 = 1;
	dm(counter) = r2;
	
	rti;
	
.section/pm seg_pmco;
SRU_Init:
	
	// Route SPORT0_FS signal to DAI pin 5
	SRU(SPORT0_FS_O,DAI_PB05_I);
	SRU(HIGH,PBEN05_I);
	
	// Route SPORT1_CLK signal to DAI pin 7
	SRU(DAI_PB07_O,SPORT1_CLK_I);
	SRU(LOW,PBEN07_I);
	
	// Route SPORT1_FS signal to DAI pin 9
	SRU(DAI_PB09_O,SPORT1_FS_I);
	SRU(LOW,PBEN09_I);
	
	// Route SPORT1_DA signal to DAI pin 11
	SRU(DAI_PB11_O,SPORT1_DA_I);
	SRU(LOW,PBEN11_I);
	
	rts;
